FromJson

Trait FromJson 

pub trait FromJson {
    // Required method
    fn from_json(json: &JsonObject) -> Result<Self, JsonParseError>
       where Self: Sized;
}
FromJs is a trait that allows any conforming structs to be converted from a JSON format.

A default implemenation is most easily obtained by deriving this trait.

Required Methods

fn from_json(json: &JsonObject) -> Result<Self, JsonParseError>
where Self: Sized,

Implementors